@@ -228,27 +228,27 @@ class FargateToDynamoDB(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="container")
     def container(self) -> aws_cdk.aws_ecs.ContainerDefinition:
         return typing.cast(aws_cdk.aws_ecs.ContainerDefinition, jsii.get(self, "container"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="dynamoTableInterface")
     def dynamo_table_interface(self) -> aws_cdk.aws_dynamodb.ITable:
         return typing.cast(aws_cdk.aws_dynamodb.ITable, jsii.get(self, "dynamoTableInterface"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="service")
     def service(self) -> aws_cdk.aws_ecs.FargateService:
         return typing.cast(aws_cdk.aws_ecs.FargateService, jsii.get(self, "service"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="vpc")
     def vpc(self) -> aws_cdk.aws_ec2.IVpc:
         return typing.cast(aws_cdk.aws_ec2.IVpc, jsii.get(self, "vpc"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="dynamoTable")
     def dynamo_table(self) -> typing.Optional[aws_cdk.aws_dynamodb.Table]:
         return typing.cast(typing.Optional[aws_cdk.aws_dynamodb.Table], jsii.get(self, "dynamoTable"))
@@ -316,11 +316,11 @@ class FargateToDynamoDBProps:
         :param vpc_props: Optional custom properties for a VPC the construct will create. This VPC will be used by the new Fargate service the construct creates (that's why targetGroupProps can't include a VPC). Providing both this and existingVpc is an error. An DynamoDB Interface endpoint will be included in this VPC. Default: - none
         '''
         if isinstance(cluster_props, dict):
-            cluster_props = aws_cdk.aws_ecs.ClusterProps(**cluster_props)
+            cluster_props = ClusterProps(**cluster_props)
         if isinstance(dynamo_table_props, dict):
-            dynamo_table_props = aws_cdk.aws_dynamodb.TableProps(**dynamo_table_props)
+            dynamo_table_props = TableProps(**dynamo_table_props)
         if isinstance(vpc_props, dict):
-            vpc_props = aws_cdk.aws_ec2.VpcProps(**vpc_props)
+            vpc_props = VpcProps(**vpc_props)
         if __debug__:
             type_hints = typing.get_type_hints(FargateToDynamoDBProps.__init__)
             check_type(argname="argument public_api", value=public_api, expected_type=type_hints["public_api"])
